ArxivLens
ArXiv cs.NE cs.CV cs.LG

A Simple Method to Reduce Off-chip Memory Accesses on Convolutional Neural Networks

Doyun Kim, Kyoung-Young Kim, Sanghyuck Ha, Sangsoo Ko

1901.09614 Published Jan 29, 2019
Read paper
More tools
View PDF
At a glance AI-generated · verify against the paper

This paper proposes a simple algorithm to minimize off-chip memory accesses in convolutional neural networks by optimizing on-chip memory usage in neural process units. The method effectively reduces off-chip memory accesses by 1/50 and achieves a 97.59% reduction in feature-map data transfer for Inception-V3 on Samsung's Exynos NPU.

Abstract

For convolutional neural networks, a simple algorithm to reduce off-chip memory accesses is proposed by maximally utilizing on-chip memory in a neural process unit. Especially, the algorithm provides an effective way to process a module which consists of multiple branches and a merge layer. For Inception-V3 on Samsung's NPU in Exynos, our evaluation shows that the proposed algorithm makes off-chip memory accesses reduced by 1/50, and accordingly achieves 97.59 % reduction in the amount of feature-map data to be transferred from/to off-chip memory.

AI Key Findings

Get AI-generated insights about this paper's methodology, results, significance, and more — available when analysis has been generated.

Paper preview View the original document Preview of the original paper

How to Cite This Paper

Reference manager: RIS EndNote

Discussion 0

This website uses cookies to ensure you get the best experience. Learn more